/// <reference types="node" />
import { S3 } from 'aws-sdk';
import { Readable, Writable } from "stream";
import { Driver, ListCloudFilesOptions, ListCloudFilesResult } from "./driver";
import { BucketFile, BucketType } from './types';
declare type AwsFile = S3.Object & {
    ContentType?: string;
};
export interface S3DriverCfg {
    bucketName: string;
    access_key_id: string;
    access_key_secret: string;
}
export declare function getS3Driver(cfg: S3DriverCfg): Promise<S3Driver>;
export declare class S3Driver implements Driver<AwsFile> {
    private s3;
    private baseParams;
    get type(): BucketType;
    get name(): string;
    constructor(s3: S3, bucketName: string);
    toFile(awsFile: AwsFile): Omit<BucketFile, 'bucket'>;
    getPath(obj: AwsFile): string;
    exists(path: string): Promise<boolean>;
    getCloudFile(path: string): Promise<AwsFile | null>;
    listCloudFiles(opts: ListCloudFilesOptions): Promise<ListCloudFilesResult<AwsFile>>;
    copyCloudFile(cf: AwsFile, dest: BucketFile): Promise<void>;
    downloadCloudFile(rawFile: AwsFile, localPath: string): Promise<void>;
    uploadCloudFile(localPath: string, remoteFilePath: string, contentType?: string): Promise<AwsFile>;
    downloadAsText(path: string): Promise<string>;
    uploadCloudContent(path: string, content: string, contentType?: string): Promise<void>;
    createReadStream(path: string): Promise<Readable>;
    createWriteStream(path: string, contentType?: string): Promise<Writable>;
    deleteCloudFile(path: string): Promise<boolean>;
}
export {};
