/// <reference types="node" />
import { Bucket as GoogleBucket, File as GoogleFile } from '@google-cloud/storage';
import { Readable, Writable } from "stream";
import { Driver, ListCloudFilesOptions, ListCloudFilesResult } from "./driver";
import { BucketFile, BucketType } from './types';
export declare function getGsDriver(cfg: GsDriverCfg): Promise<GcpDriver>;
export interface GsDriverCfg {
    bucketName: string;
    project_id: string;
    client_email: string;
    private_key: string;
}
declare class GcpDriver implements Driver<GoogleFile> {
    readonly googleBucket: GoogleBucket;
    get type(): BucketType;
    get name(): string;
    constructor(googleBucket: GoogleBucket);
    toFile(googleFile: GoogleFile): Omit<BucketFile, 'bucket'>;
    getPath(obj: GoogleFile): string;
    exists(path: string): Promise<boolean>;
    getCloudFile(path: string): Promise<GoogleFile | null>;
    /**
     *
     * @param path prefix path or glob (the string before the first '*' will be used as prefix)
     */
    listCloudFiles(opts: ListCloudFilesOptions): Promise<ListCloudFilesResult>;
    downloadCloudFile(cf: GoogleFile, localPath: string): Promise<void>;
    uploadCloudFile(localFilePath: string, remoteFilePath: string, contentType?: string): Promise<GoogleFile>;
    copyCloudFile(cf: GoogleFile, dest: BucketFile): Promise<void>;
    deleteCloudFile(path: string): Promise<boolean>;
    downloadAsText(path: string): Promise<string>;
    uploadCloudContent(path: string, content: string, contentType?: string): Promise<void>;
    createReadStream(path: string): Promise<Readable>;
    createWriteStream(path: string, contentType?: string): Promise<Writable>;
}
export {};
