"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getBucket = exports.urlSigner = exports.signUrl = void 0;
const bucket_1 = require("./bucket");
const driver_aws_1 = require("./driver-aws");
const driver_gcp_1 = require("./driver-gcp");
const driver_minio_1 = require("./driver-minio");
var url_signer_1 = require("./url-signer");
Object.defineProperty(exports, "signUrl", { enumerable: true, get: function () { return url_signer_1.signUrl; } });
Object.defineProperty(exports, "urlSigner", { enumerable: true, get: function () { return url_signer_1.urlSigner; } });
async function getBucket(options) {
    var _a;
    if (options == null) {
        throw new Error(`ERROR - cloud-bucket - Cannot getBucket with options ${options}`);
    }
    const log = (_a = options.log) !== null && _a !== void 0 ? _a : false; // by default, false. 
    // if has .project_id, assume GcpBucket
    const driver = await getDriver(options);
    const bucket = bucket_1.newBucket({ driver, log });
    return bucket;
}
exports.getBucket = getBucket;
async function getDriver(driverCfg) {
    if (isGsDriverCfg(driverCfg)) {
        return driver_gcp_1.getGsDriver(driverCfg);
    }
    else if (isMinioDriverCfg(driverCfg)) { // IMPORTANT MUST be before S3Driver, because same access_key... 
        return driver_minio_1.getMinioDriver(driverCfg);
    }
    else if (isS3DriverCfg(driverCfg)) {
        return driver_aws_1.getS3Driver(driverCfg);
    }
    else {
        throw new Error(`bucket config does not seem to be valid (only support Gcp and Aws for now)`);
    }
}
function isGsDriverCfg(opts) {
    return opts.hasOwnProperty('project_id');
}
function isS3DriverCfg(opts) {
    return opts.hasOwnProperty('access_key_id');
}
function isMinioDriverCfg(opts) {
    return opts.hasOwnProperty('minio_endpoint') && opts.minio_endpoint != null;
}
