declare type CloudSignUrlOptions = {
    type: 's3' | 'gs';
    expires: number;
    keyName: string;
    key: string;
};
export declare type SignUrlOptions = CloudSignUrlOptions | {
    type: 'minio';
};
export declare function signUrl(url: string, opts: SignUrlOptions): string;
/**
 * Return a path signer based on a baseUrl and the sign option. This is the optimal way to sign many urls and should be typically used over the signUrl method.
 *
 * ```ts
 * const signer = urlSigner('https://.../some/dir/');
 * const signedUrls = ['my/image-001.jpeg', 'my/file.json'].map(signer);
 * ```
 *
 * Performance benefits:
 *
 * - s3 - This takes full advantage of the aws 'directory signing' like urlSigner('https://.../some/dir/*', opts) will create one signature for the folder and apply it to each sub path.
 * - gs - While google storage does not have the same capability, there are small benefits as well on some base64 object creation (not much though). However, because of GCP small key, the signature is much faster than s3 (about 10x)
 */
export declare function urlSigner(baseUrl: string, opts: SignUrlOptions): (pathFromBaseUrl: string) => string;
export {};
